==> 0.1.1.tar.gz: android/src/main/kotlin/com/bundle/bundle_rave_pay/BundleRavePayPlugin.kt <==
package com.bundle.bundle_rave_pay

import android.app.Activity
import android.content.Intent
import android.util.Log
import com.bundle.bundle_rave_pay.RaveConstants.RAVE_PARAMS
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar


class BundleRavePayPlugin(var activity: Activity) : MethodCallHandler {

    lateinit var outerResult: Result


    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "bundle_rave_pay")

            channel.setMethodCallHandler(BundleRavePayPlugin(registrar.activity()))
        }
    }

    override fun onMethodCall(call: MethodCall, result: Result) {
        outerResult = result
        if (call.method == "initializePayment") {

            val arguments = call.argument<HashMap<String, String>>("body")!!

            val amount = arguments["amount"]!!.toDouble()

            val cvv = if (arguments.containsKey("cvv")) {
                arguments["cvv"]
            } else {
                ""
            }

            val cardExpiry = if (arguments.containsKey("cardExpiry")) {
                arguments["cardExpiry"]
            } else {
                ""
            }

            val cardNumber = if (arguments.containsKey("cardNumber")) {
                arguments["cardNumber"]
            } else {
                ""
            }

            val firstName = if (arguments.containsKey("firstName")) {
                arguments["firstName"]
            } else {
                ""
            }

            val lastName = if (arguments.containsKey("lastName")) {
                arguments["lastName"]
            } else {
                ""
            }

            val country = arguments["country"]!!
            val currencyCode = arguments["currencyCode"]!!
            val email = arguments["email"]!!

            val txRef = arguments["transactionReference"]!!

            val isLive = arguments["isLive"]!!.toBoolean()
            val publicKey = arguments["publicKey"]!!
            val encryptionKey = arguments["encryptionKey"]!!
            val secretKey = arguments["secretKey"]!!

            val narration = arguments["narration"]!!

            val isCard = if (arguments["isCard"] != null) {
                arguments["isCard"]!!.toBoolean()
            } else {
                false
            }

            val saveCard = if (arguments["saveCard"] != null) {
                arguments["saveCard"]!!.toBoolean()
            } else {
                false
            }

            val isAccount = if (arguments["isAccount"] != null) {
                arguments["isAccount"]!!.toBoolean()
            } else {
                false
            }

            val isBankTransfer = if (arguments["isBankTransfer"] != null) {
                arguments["isBankTransfer"]!!.toBoolean()
            } else {
                false
            }

            Log.i("PROGRAM RESPONSE", isCard.toString())

            if(!(isCard || isAccount || isBankTransfer)){
                result.error("no payment option passed", null, null)
            }
            val bundleData = BundleData(amount, cvv, cardExpiry, cardNumber, publicKey, encryptionKey, secretKey, country, currencyCode, email,
                    firstName, lastName, narration, txRef, isLive, saveCard, isCard, isAccount, isBankTransfer)


            cardPayment(bundleData)
            result.success(true)
        } else {
            result.notImplemented()
        }
    }

    private fun cardPayment(cardBundle: BundleData): Boolean {
        val intent = Intent(activity, RavePayActivity::class.java)
        intent.putExtra(RAVE_PARAMS, cardBundle)
        activity.startActivityForResult(intent, 404)

        return true
    }

}

==> 0.2.1.tar.gz: android/src/main/kotlin/com/bundle/bundle_rave_pay/BundleRavePayPlugin.kt <==
package com.bundle.bundle_rave_pay

import android.app.Activity
import android.content.Intent
import android.util.Log
import com.bundle.bundle_rave_pay.RaveConstants.RAVE_PARAMS
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar


class BundleRavePayPlugin(var activity: Activity) : MethodCallHandler {

    lateinit var outerResult: Result


    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "bundle_rave_pay")

            channel.setMethodCallHandler(BundleRavePayPlugin(registrar.activity()))
        }
    }

    override fun onMethodCall(call: MethodCall, result: Result) {
        outerResult = result
        if (call.method == "initializePayment") {

            val arguments = call.argument<HashMap<String, String>>("body")!!

            val amount = arguments["amount"]!!.toDouble()

            val cvv = if (arguments.containsKey("cvv")) {
                arguments["cvv"]
            } else {
                ""
            }

            val cardExpiry = if (arguments.containsKey("cardExpiry")) {
                arguments["cardExpiry"]
            } else {
                ""
            }

            val cardNumber = if (arguments.containsKey("cardNumber")) {
                arguments["cardNumber"]
            } else {
                ""
            }

            val firstName = if (arguments.containsKey("firstName")) {
                arguments["firstName"]
            } else {
                ""
            }

            val lastName = if (arguments.containsKey("lastName")) {
                arguments["lastName"]
            } else {
                ""
            }

            val country = arguments["country"]!!
            val currencyCode = arguments["currencyCode"]!!
            val email = arguments["email"]!!

            val txRef = arguments["transactionReference"]!!

            val isLive = arguments["isLive"]!!.toBoolean()
            val publicKey = arguments["publicKey"]!!
            val encryptionKey = arguments["encryptionKey"]!!
            val secretKey = arguments["secretKey"]!!

            val narration = arguments["narration"]!!
            
            val isCard = if (arguments["paymentMethod"] != null) {
                arguments["paymentMethod"]!! == "card"
            } else {
                false
            }

            val saveCard = if (arguments["saveCard"] != null) {
                arguments["saveCard"]!!.toBoolean()
            } else {
                false
            }

            val isAccount = if (arguments["paymentMethod"] != null) {
                arguments["paymentMethod"]!! == "account"
            } else {
                false
            }

            val isBankTransfer = if (arguments["paymentMethod"] != null) {
                arguments["paymentMethod"]!! == "transfer"
            } else {
                false
            }

            Log.i("PROGRAM RESPONSE", isCard.toString())

            if(!(isCard || isAccount || isBankTransfer)){
                result.error("no payment option passed", null, null)
            }
            val bundleData = BundleData(amount, cvv, cardExpiry, cardNumber, publicKey, encryptionKey, secretKey, country, currencyCode, email,
                    firstName, lastName, narration, txRef, isLive, saveCard, isCard, isAccount, isBankTransfer)


            cardPayment(bundleData)
            result.success(true)
        } else if (call.method == "initializeMoMoPayment") {

        } else {
            result.notImplemented()
        }
    }

    private fun cardPayment(cardBundle: BundleData): Boolean {
        val intent = Intent(activity, RavePayActivity::class.java)
        intent.putExtra(RAVE_PARAMS, cardBundle)
        activity.startActivityForResult(intent, 404)

        return true
    }

    private fun momoPayment(cardBundle: BundleData) {
        // TODO: Implement f(x)
    }

}
